==> trade-center-api-2.4.15-20220315.025912-29-sources.jar: cn/com/duiba/order/center/api/tool/OrderUtils.java <==
package cn.com.duiba.order.center.api.tool;

import cn.com.duiba.order.center.api.constant.FlowStageConstant;
import cn.com.duiba.order.center.api.constant.ItemSourceEnum;
import cn.com.duiba.order.center.api.constant.OrderTypeEnum;
import cn.com.duiba.order.center.api.constant.StatusIntEnum;
import cn.com.duiba.order.center.api.dto.AmbPostsaleOrdersDto;
import cn.com.duiba.order.center.api.dto.AmbSubOrdersDto;
import cn.com.duiba.order.center.api.dto.OrderItemDto;
import cn.com.duiba.order.center.api.dto.OrdersDto;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang.StringUtils;

import java.util.Objects;

/**
 * Created by zhangshun on 2018/12/24,09:33:51.
 */
public class OrderUtils {
    //订单Extra字段的jsonKey 拼团活动团id
    public static final String GROUP_ID = "groupId";
    //订单Extra字段的jsonKey 购物车商品来源，兑吧 duiba  混合mix 自有 dlp
    public static final String ITEM_SOURCE = "itemSource";

    private OrderUtils() {

    }

    /**
     * 是否新订单
     *
     * @param order
     * @return
     */
    public static Boolean isNewOrder(OrdersDto order) {
        return Objects.isNull(order.getAppItemId()) && Objects.isNull(order.getItemId());
    }

    public static void setExtraJson(OrdersDto order, String jsonKey, Object jsonValue) {
        JSONObject jsonObject = new JSONObject();
        if(StringUtils.isNotBlank(order.getExtraInfo())){
            jsonObject = JSONObject.parseObject(order.getExtraInfo());
        }
        jsonObject.put(jsonKey, jsonValue);
        order.setExtraInfo(jsonObject.toJSONString());
    }

    public static Long getGroupId(OrdersDto order) {
        if(StringUtils.isNotBlank(order.getExtraInfo())){
            JSONObject jsonObject = JSONObject.parseObject(order.getExtraInfo());
            return jsonObject.getLong(GROUP_ID);
        }
        return null;
    }

    public static StatusIntEnum getStatus(OrdersDto dto, AmbSubOrdersDto subDto) {
        if (Objects.equals(dto.getRelationType(),OrdersDto.RelationTypeGroupBuy) && FlowStageConstant.consumerPayComplete.equals(dto.getFlowworkStage())) {
            //如果是拼团单并且状态是已支付，返回拼团中
            return StatusIntEnum.GROUP_BUYING;
        }
        if (FlowStageConstant.consumerPayStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.WAIT_PAY;
        }
        // 买家付款完成, 下个状态为: 等待商家审核
        if (FlowStageConstant.auditStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.WAIT_AUDIT;
        }
        //待发货
        if (OrderTypeEnum.OBJECT.getType().equals(dto.getType()) && FlowStageConstant.supplierExchangeStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.WAIT_SEND;
        }

        // 成功
        if (FlowStageConstant.successComplete.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.SUCCESS;
        }
        Integer statusInt = dto.getStatusInt();
        if (statusInt != null && statusInt >= StatusIntEnum.WAIT_PAY.getCode()) {
            //新逻辑 展示 已取消，已失效，异常
            if (FlowStageConstant.failComplete.equalsIgnoreCase(dto.getFlowworkStage())) {
                return StatusIntEnum.ofValue(statusInt);
            }
            // 商家已发货, 下个状态为: 确认收货
            if (FlowStageConstant.afterSendStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
                return StatusIntEnum.ofValue(statusInt);
            }
        } else {
            // 商家已发货, 下个状态为: 确认收货
            if (FlowStageConstant.afterSendStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
                // 已收货
                if (Objects.nonNull(subDto) &&
                        Objects.equals(AmbSubOrdersDto.SubOrdersShipStatusReceived, subDto.getShipStatus())) {
                    return StatusIntEnum.RECEIVE;
                }
                // 已发货
                return StatusIntEnum.WAIT_RECEIVE;
            }
            // 失败
            if (OrdersDto.StatusFAil.equalsIgnoreCase(dto.getStatus()) ||
                    FlowStageConstant.create2Fail.equalsIgnoreCase(dto.getFlowworkStage())) {
                //老的都叫失败
                return StatusIntEnum.FAIL;
            }
        }
        return StatusIntEnum.PROCESSING;
    }

    /**
     * 是否普兑商品
     * @param order
     * @return
     */
    public static boolean isMallOrder(OrdersDto order){
        if(OrdersDto.ChargeModeMall.equals(order.getChargeMode()) || OrdersDto.ChargeModeApi.equals(order.getChargeMode())){
            return true;
        }
        return false;
    }

    /**
     * 是否普兑商品
     * @param chargeMode
     * @return
     */
    public static boolean isMallOrder(String chargeMode){
        if(OrdersDto.ChargeModeMall.equals(chargeMode) || OrdersDto.ChargeModeApi.equals(chargeMode)){
            return true;
        }
        return false;
    }
    /**
     * 是否购物车
     * @param chargeMode
     * @return
     */
    public static boolean isShoppingCart(OrdersDto order){
        if(order.getAppItemId() == null && order.getItemId() == null){
            return true;
        }
        return false;
    }

    /**
     * 是否是兑吧采购商品
     * @param ordersDto
     * @return
     */
    public static boolean isPurchaseOrder(OrdersDto ordersDto) {
        //判断是不是供应商商品
        boolean ret = false;
        //如果是兑吧实物商品
        if(ordersDto.getItemId() != null && StringUtils.isNotBlank(ordersDto.getExtraInfo())){
            JSONObject extra = JSONObject.parseObject(ordersDto.getExtraInfo());
            if(extra != null){
                Long supplierId = extra.getLong("supplierId");
                if(supplierId != null){
                    ret = true;
                }
            }
        }

        return ret;
    }

    /**
     * 是否处理中的售后状态
     * @param postsaleStatus
     * @return
     */
    public static boolean isProcessStatus(String postsaleStatus) {
        return AmbPostsaleOrdersDto.POSTSALE_STATUS_WAIT.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE_NO_GOODS.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_MERCHANTS_RECEIVED.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_REFUNDING.equals(postsaleStatus);
    }
    /**
     * 是否处理中的售后状态不包含退款中
     * 讲道理处理中应该都要包含退款中的，不知道之前为什么不包含
     * @param postsaleStatus
     * @return
     */
    public static boolean isProcessStatusWithoutRefunding(String postsaleStatus) {
        return AmbPostsaleOrdersDto.POSTSALE_STATUS_WAIT.equals(postsaleStatus)
                || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE.equals(postsaleStatus)
                || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE_NO_GOODS.equals(postsaleStatus)
                || AmbPostsaleOrdersDto.POSTSALE_STATUS_MERCHANTS_RECEIVED.equals(postsaleStatus);
    }

    //是否新购物车
    public static boolean isNewShoppingCart(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (StringUtils.isNotBlank(itemSource)) {
            return true;
        } else {
            return false;
        }
    }
    /**
     * 是否新购物车全部兑吧商品
     * @param order
     * @return
     */
    public static boolean isAllDuibaItem(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (ItemSourceEnum.DUIBA.getSource().equals(itemSource)) {
            //如果是自有类型说明不包含兑吧商品
            return true;
        } else {
            return false;
        }
    }

    /**
     * 是否新购物车混合商品（包含自有和兑吧商品）
     * @param order
     * @return
     */
    public static boolean isMixItem(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (ItemSourceEnum.MIX.getSource().equals(itemSource)) {
            //如果是自有类型说明不包含兑吧商品
            return true;
        } else {
            return false;
        }
    }
    /**
     * 是否新购物车全部自有商品
     * @param order
     * @return
     */
    public static boolean isAllDlpItem(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (ItemSourceEnum.DLP.getSource().equals(itemSource)) {
            //如果是自有类型说明不包含兑吧商品
            return true;
        } else {
            return false;
        }
    }

    public static boolean hasDuibaItem(OrdersDto order) {
        //是否包含兑吧商品
        return isAllDuibaItem(order) || isMixItem(order);
    }

    public static boolean hasDlpItem(OrdersDto order) {
        //是否包含自有商品
        return isAllDuibaItem(order) || isMixItem(order);
    }

    public static String getExtraValueByKey(OrdersDto ordersDto, String extraKey) {
        JSONObject jsonObject = JSONObject.parseObject(ordersDto.getExtraInfo());
        if (jsonObject == null || StringUtils.isBlank(jsonObject.getString(extraKey))) {
            return null;
        }
        return jsonObject.getString(extraKey);
    }

    public static String getOrderNum(Long orderId) {
        StringBuilder orderNumC=new StringBuilder();
        String orderNum = orderId + "";
        orderNumC.append(orderNum).insert(orderNum.length() - 4, "C");
        return orderNumC.toString();
    }

    /**
     * 获取分销商父订单号，兼容老数据
     * @param orderExtraInfo
     * @param orderItemExtraInfo
     * @return
     */
    public static String getDistributorsParentOrderCode(String orderExtraInfo, String orderItemExtraInfo) {
        if (StringUtils.isBlank(orderExtraInfo) && StringUtils.isBlank(orderItemExtraInfo)) {
            return null;
        }
        JSONObject orderExtraInfoJson = JSON.parseObject(orderExtraInfo);
        String orderCode = null;
        if (orderExtraInfoJson != null) {
            orderCode = orderExtraInfoJson.getString(OrdersDto.DISTRIBUTORS_PARENT_ORDER_ID);
        }
        if (StringUtils.isBlank(orderCode) && StringUtils.isNotBlank(orderItemExtraInfo)) {
            JSONObject orderItemExtraInfoJson = JSON.parseObject(orderItemExtraInfo);
            if (orderItemExtraInfoJson != null) {
                orderCode = StringUtils.isBlank(orderCode) ? orderItemExtraInfoJson.getString("distributorsParentOrderId") : orderCode;
            }
        }
        return orderCode;
    }

    /**
     * 获取分销商父订单号，兼容老数据
     * @param orderExtraInfo
     * @param orderItemExtraInfo
     * @return
     */
    public static String getSupplierParentOrderCode(String orderExtraInfo, String orderItemExtraInfo) {
        if (StringUtils.isBlank(orderExtraInfo) && StringUtils.isBlank(orderItemExtraInfo)) {
            return null;
        }
        JSONObject orderExtraInfoJson = JSON.parseObject(orderExtraInfo);
        String orderCode = null;
        if (orderExtraInfoJson != null) {
            orderCode = orderExtraInfoJson.getString(OrdersDto.SUPPLIER_PARENT_ORDER_ID);
        }
        if (StringUtils.isBlank(orderCode) && StringUtils.isNotBlank(orderItemExtraInfo)) {
            JSONObject orderItemExtraInfoJson = JSON.parseObject(orderItemExtraInfo);
            if (orderItemExtraInfoJson != null) {
                orderCode = StringUtils.isBlank(orderCode) ? orderItemExtraInfoJson.getString("supplierParentOrderId") : orderCode;
            }
        }
        return orderCode;
    }
}

==> trade-center-api-3.0.14-sources.jar: cn/com/duiba/order/center/api/tool/OrderUtils.java <==
package cn.com.duiba.order.center.api.tool;

import cn.com.duiba.order.center.api.constant.ExtraInfoToEsRelationEnum;
import cn.com.duiba.order.center.api.constant.FlowStageConstant;
import cn.com.duiba.order.center.api.constant.ItemSourceEnum;
import cn.com.duiba.order.center.api.constant.OrderTypeEnum;
import cn.com.duiba.order.center.api.constant.StatusIntEnum;
import cn.com.duiba.order.center.api.dto.AmbPostsaleOrdersDto;
import cn.com.duiba.order.center.api.dto.AmbSubOrdersDto;
import cn.com.duiba.order.center.api.dto.OrderItemDto;
import cn.com.duiba.order.center.api.dto.OrdersDto;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang.StringUtils;

import java.util.Objects;

/**
 * Created by zhangshun on 2018/12/24,09:33:51.
 */
public class OrderUtils {
    //订单Extra字段的jsonKey 拼团活动团id
    public static final String GROUP_ID = "groupId";
    //订单Extra字段的jsonKey 购物车商品来源，兑吧 duiba  混合mix 自有 dlp
    public static final String ITEM_SOURCE = "itemSource";

    private OrderUtils() {

    }

    /**
     * 是否新订单
     *
     * @param order
     * @return
     */
    public static Boolean isNewOrder(OrdersDto order) {
        return Objects.isNull(order.getAppItemId()) && Objects.isNull(order.getItemId());
    }

    public static void setExtraJson(OrdersDto order, String jsonKey, Object jsonValue) {
        JSONObject jsonObject = new JSONObject();
        if(StringUtils.isNotBlank(order.getExtraInfo())){
            jsonObject = JSONObject.parseObject(order.getExtraInfo());
        }
        jsonObject.put(jsonKey, jsonValue);
        order.setExtraInfo(jsonObject.toJSONString());
    }

    //如果订单存储的时候，需要将额外字段存入到 es 目前必须经过改 extra_info 字段传输，data-sync 会根据字段名称，进行 es 同步
    public static void extraInfoToEsSave(OrdersDto order, ExtraInfoToEsRelationEnum extraInfoToEsRelationEnum, Object jsonValue) {
        JSONObject jsonObject = new JSONObject();
        if(StringUtils.isNotBlank(order.getExtraInfo())){
            jsonObject = JSONObject.parseObject(order.getExtraInfo());
        }
        jsonObject.put(extraInfoToEsRelationEnum.getCustomEsFieldName().getFieldName(), jsonValue);
        order.setExtraInfo(jsonObject.toJSONString());
    }

    public static Long getGroupId(OrdersDto order) {
        if(StringUtils.isNotBlank(order.getExtraInfo())){
            JSONObject jsonObject = JSONObject.parseObject(order.getExtraInfo());
            return jsonObject.getLong(GROUP_ID);
        }
        return null;
    }

    public static StatusIntEnum getStatus(OrdersDto dto, AmbSubOrdersDto subDto) {
        if (Objects.equals(dto.getRelationType(),OrdersDto.RelationTypeGroupBuy) && FlowStageConstant.consumerPayComplete.equals(dto.getFlowworkStage())) {
            //如果是拼团单并且状态是已支付，返回拼团中
            return StatusIntEnum.GROUP_BUYING;
        }
        if (FlowStageConstant.consumerPayStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.WAIT_PAY;
        }
        // 买家付款完成, 下个状态为: 等待商家审核
        if (FlowStageConstant.auditStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.WAIT_AUDIT;
        }
        //待发货
        if (OrderTypeEnum.OBJECT.getType().equals(dto.getType()) && FlowStageConstant.supplierExchangeStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.WAIT_SEND;
        }

        // 成功
        if (FlowStageConstant.successComplete.equalsIgnoreCase(dto.getFlowworkStage())) {
            return StatusIntEnum.SUCCESS;
        }
        Integer statusInt = dto.getStatusInt();
        if (statusInt != null && statusInt >= StatusIntEnum.WAIT_PAY.getCode()) {
            //新逻辑 展示 已取消，已失效，异常
            if (FlowStageConstant.failComplete.equalsIgnoreCase(dto.getFlowworkStage())) {
                return StatusIntEnum.ofValue(statusInt);
            }
            // 商家已发货, 下个状态为: 确认收货
            if (FlowStageConstant.afterSendStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
                return StatusIntEnum.ofValue(statusInt);
            }
        } else {
            // 商家已发货, 下个状态为: 确认收货
            if (FlowStageConstant.afterSendStarted.equalsIgnoreCase(dto.getFlowworkStage())) {
                // 已收货
                if (Objects.nonNull(subDto) &&
                        Objects.equals(AmbSubOrdersDto.SubOrdersShipStatusReceived, subDto.getShipStatus())) {
                    return StatusIntEnum.RECEIVE;
                }
                // 已发货
                return StatusIntEnum.WAIT_RECEIVE;
            }
            // 失败
            if (OrdersDto.StatusFAil.equalsIgnoreCase(dto.getStatus()) ||
                    FlowStageConstant.create2Fail.equalsIgnoreCase(dto.getFlowworkStage())) {
                //老的都叫失败
                return StatusIntEnum.FAIL;
            }
        }
        return StatusIntEnum.PROCESSING;
    }

    /**
     * 是否普兑商品
     * @param order
     * @return
     */
    public static boolean isMallOrder(OrdersDto order){
        if(OrdersDto.ChargeModeMall.equals(order.getChargeMode()) || OrdersDto.ChargeModeApi.equals(order.getChargeMode())){
            return true;
        }
        return false;
    }

    /**
     * 是否普兑商品
     * @param chargeMode
     * @return
     */
    public static boolean isMallOrder(String chargeMode){
        if(OrdersDto.ChargeModeMall.equals(chargeMode) || OrdersDto.ChargeModeApi.equals(chargeMode)){
            return true;
        }
        return false;
    }
    /**
     * 是否购物车
     * @param chargeMode
     * @return
     */
    public static boolean isShoppingCart(OrdersDto order){
        if(order.getAppItemId() == null && order.getItemId() == null){
            return true;
        }
        return false;
    }

    /**
     * 是否是兑吧采购商品
     * @param ordersDto
     * @return
     */
    public static boolean isPurchaseOrder(OrdersDto ordersDto) {
        //判断是不是供应商商品
        boolean ret = false;
        //如果是兑吧实物商品
        if(ordersDto.getItemId() != null && StringUtils.isNotBlank(ordersDto.getExtraInfo())){
            JSONObject extra = JSONObject.parseObject(ordersDto.getExtraInfo());
            if(extra != null){
                Long supplierId = extra.getLong("supplierId");
                if(supplierId != null){
                    ret = true;
                }
            }
        }

        return ret;
    }

    /**
     * 是否处理中的售后状态
     * @param postsaleStatus
     * @return
     */
    public static boolean isProcessStatus(String postsaleStatus) {
        return AmbPostsaleOrdersDto.POSTSALE_STATUS_WAIT.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE_NO_GOODS.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_MERCHANTS_RECEIVED.equals(postsaleStatus)
            || AmbPostsaleOrdersDto.POSTSALE_STATUS_REFUNDING.equals(postsaleStatus);
    }
    /**
     * 是否处理中的售后状态不包含退款中
     * 讲道理处理中应该都要包含退款中的，不知道之前为什么不包含
     * @param postsaleStatus
     * @return
     */
    public static boolean isProcessStatusWithoutRefunding(String postsaleStatus) {
        return AmbPostsaleOrdersDto.POSTSALE_STATUS_WAIT.equals(postsaleStatus)
                || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE.equals(postsaleStatus)
                || AmbPostsaleOrdersDto.POSTSALE_STATUS_AGREE_NO_GOODS.equals(postsaleStatus)
                || AmbPostsaleOrdersDto.POSTSALE_STATUS_MERCHANTS_RECEIVED.equals(postsaleStatus);
    }

    //是否新购物车
    public static boolean isNewShoppingCart(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (StringUtils.isNotBlank(itemSource)) {
            return true;
        } else {
            return false;
        }
    }
    /**
     * 是否新购物车全部兑吧商品
     * @param order
     * @return
     */
    public static boolean isAllDuibaItem(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (ItemSourceEnum.DUIBA.getSource().equals(itemSource)) {
            //如果是自有类型说明不包含兑吧商品
            return true;
        } else {
            return false;
        }
    }

    /**
     * 是否新购物车混合商品（包含自有和兑吧商品）
     * @param order
     * @return
     */
    public static boolean isMixItem(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (ItemSourceEnum.MIX.getSource().equals(itemSource)) {
            //如果是自有类型说明不包含兑吧商品
            return true;
        } else {
            return false;
        }
    }
    /**
     * 是否新购物车全部自有商品
     * @param order
     * @return
     */
    public static boolean isAllDlpItem(OrdersDto order) {
        String itemSource = getExtraValueByKey(order, ITEM_SOURCE);
        if (ItemSourceEnum.DLP.getSource().equals(itemSource)) {
            //如果是自有类型说明不包含兑吧商品
            return true;
        } else {
            return false;
        }
    }

    public static boolean hasDuibaItem(OrdersDto order) {
        //是否包含兑吧商品
        return isAllDuibaItem(order) || isMixItem(order);
    }

    public static boolean hasDlpItem(OrdersDto order) {
        //是否包含自有商品
        return isAllDlpItem(order) || isMixItem(order);
    }

    public static String getExtraValueByKey(OrdersDto ordersDto, String extraKey) {
        JSONObject jsonObject = JSONObject.parseObject(ordersDto.getExtraInfo());
        if (jsonObject == null || StringUtils.isBlank(jsonObject.getString(extraKey))) {
            return null;
        }
        return jsonObject.getString(extraKey);
    }

    public static String getOrderNum(Long orderId) {
        StringBuilder orderNumC=new StringBuilder();
        String orderNum = orderId + "";
        orderNumC.append(orderNum).insert(orderNum.length() - 4, "C");
        return orderNumC.toString();
    }

    /**
     * 获取分销商父订单号，兼容老数据
     * @param orderExtraInfo
     * @param orderItemExtraInfo
     * @return
     */
    public static String getDistributorsParentOrderCode(String orderExtraInfo, String orderItemExtraInfo) {
        if (StringUtils.isBlank(orderExtraInfo) && StringUtils.isBlank(orderItemExtraInfo)) {
            return null;
        }
        JSONObject orderExtraInfoJson = JSON.parseObject(orderExtraInfo);
        String orderCode = null;
        if (orderExtraInfoJson != null) {
            orderCode = orderExtraInfoJson.getString(OrdersDto.DISTRIBUTORS_PARENT_ORDER_ID);
        }
        if (StringUtils.isBlank(orderCode) && StringUtils.isNotBlank(orderItemExtraInfo)) {
            JSONObject orderItemExtraInfoJson = JSON.parseObject(orderItemExtraInfo);
            if (orderItemExtraInfoJson != null) {
                orderCode = StringUtils.isBlank(orderCode) ? orderItemExtraInfoJson.getString("distributorsParentOrderId") : orderCode;
            }
        }
        return orderCode;
    }

    /**
     * 获取分销商父订单号，兼容老数据
     * @param orderExtraInfo
     * @param orderItemExtraInfo
     * @return
     */
    public static String getSupplierParentOrderCode(String orderExtraInfo, String orderItemExtraInfo) {
        if (StringUtils.isBlank(orderExtraInfo) && StringUtils.isBlank(orderItemExtraInfo)) {
            return null;
        }
        JSONObject orderExtraInfoJson = JSON.parseObject(orderExtraInfo);
        String orderCode = null;
        if (orderExtraInfoJson != null) {
            orderCode = orderExtraInfoJson.getString(OrdersDto.SUPPLIER_PARENT_ORDER_ID);
        }
        if (StringUtils.isBlank(orderCode) && StringUtils.isNotBlank(orderItemExtraInfo)) {
            JSONObject orderItemExtraInfoJson = JSON.parseObject(orderItemExtraInfo);
            if (orderItemExtraInfoJson != null) {
                orderCode = StringUtils.isBlank(orderCode) ? orderItemExtraInfoJson.getString("supplierParentOrderId") : orderCode;
            }
        }
        return orderCode;
    }
}
